@@ -10,12 +10,13 @@ from datetime import datetime
 
 from django_drf_filepond.models import TemporaryUpload
 from execnb.nbio import nb2dict, read_nb
+from matplotlib.pyplot import close
 
 from apps.nb.nbrun import NbRun
-from apps.nbworker.utils import Purpose, WorkerState, stop_event
+from apps.nbworker.utils import Purpose, stop_event
 from apps.nbworker.ws import WSClient
-from apps.storage.storage import StorageManager
 from apps.tasks.models import Task
+from apps.workers.models import WorkerState
 from apps.ws.utils import parse_params
 from widgets.manager import WidgetsManager
 
@@ -31,11 +32,21 @@ class NBWorker(WSClient):
         self.prev_body = ""
         self.prev_update_time = None
         self.prev_md5 = None
+        self.start_time = time.time()
+        self.max_idle_time = int(
+            os.environ.get("MAX_IDLE_TIME", 12 * 60 * 60)
+        )  # default idle after 12 hours
+        self.max_run_time = int(
+            os.environ.get("MAX_RUN_TIME", 24 * 60 * 60)
+        )  # default max run time is 24 hours
+        self.last_execution_time = time.time()
+        self.start_time = time.time()
+
         # monitor notebook file updates if running locally
         if "127.0.0.1" in ws_address:
             threading.Thread(target=self.nb_file_watch, daemon=True).start()
         threading.Thread(target=self.process_msgs, daemon=True).start()
-        self.ws.run_forever(ping_interval=5, ping_timeout=3)
+        self.ws.run_forever(ping_interval=10, ping_timeout=5)
 
     @staticmethod
     def md5(fname):
@@ -75,18 +86,16 @@ class NBWorker(WSClient):
             log.debug(f"Porcess msg {item}")
             json_data = json.loads(item)
 
+            self.last_execution_time = time.time()
+
             if json_data.get("purpose", "") == Purpose.InitNotebook:
                 self.init_notebook()
             elif json_data.get("purpose", "") == Purpose.RunNotebook:
                 self.run_notebook(json_data)
-            elif json_data.get("purpose", "") == Purpose.SaveNotebook:
-                self.save_notebook()
             elif json_data.get("purpose", "") == Purpose.DisplayNotebook:
                 self.display_notebook(json_data)
             elif json_data.get("purpose", "") == Purpose.ClearSession:
                 self.init_notebook()
-            elif json_data.get("purpose", "") == Purpose.WorkerPing:
-                self.worker_pong()
             elif json_data.get("purpose", "") == Purpose.CloseWorker:
                 stop_event.set()
                 self.delete_worker()
@@ -99,10 +108,26 @@ class NBWorker(WSClient):
             self.queue.task_done()
 
     def worker_pong(self):
-        self.update_worker_state(WorkerState.Running)
+        total_run_time = time.time() - self.start_time
+        elapsed_from_last_execution = time.time() - self.last_execution_time
+        log.debug(f"Total run time {total_run_time}")
+        log.debug(f"Elapsed from last execution {elapsed_from_last_execution}")
+
+        close_worker = True
+        if total_run_time > self.max_run_time:
+            self.update_worker_state(WorkerState.MaxRunTimeReached)
+        elif elapsed_from_last_execution > self.max_idle_time:
+            self.update_worker_state(WorkerState.MaxIdleTimeReached)
+        else:
+            self.update_worker_state(self.worker_state())
+            close_worker = False
+
         if self.worker_exists():
             self.send_state()
 
+        if close_worker:
+            self.queue.put(json.dumps({"purpose": Purpose.CloseWorker}))
+
     def run_notebook(self, json_params):
         log.debug(f"Run notebook with {json_params}")
         self.update_worker_state(WorkerState.Busy)
@@ -111,10 +136,9 @@ class NBWorker(WSClient):
 
         self.update_nb(widgets)
 
-        if self.is_presentation():
-            body = self.nbrun.export_html(self.nb, full_header=True)
-        else:
-            body = self.nbrun.export_html(self.nb, full_header=False)
+        self.sm.sync_output_dir()
+
+        body = self.nbrun.export_html(self.nb, full_header=self.is_presentation())
 
         # with open(f"test_{counter}.html", "w") as fout:
         #    fout.write(body)
@@ -138,10 +162,12 @@ class NBWorker(WSClient):
             )
 
             if widget_type == "File" and len(value) == 2:
+                
                 log.debug(f"Get file {value[0]} from id={value[1]}")
-                tu = TemporaryUpload.objects.get(upload_id=value[1])
-                value[1] = tu.get_file_path()
-                value[1] = value[1].replace("\\", "\\\\")
+                # tu = TemporaryUpload.objects.get(upload_id=value[1])
+                # value[1] = tu.get_file_path()
+                # value[1] = value[1].replace("\\", "\\\\")
+                value = self.sm.get_user_uploaded_file(value)
                 log.debug(f"File path is {value[1]}")
 
                 code = (
@@ -149,8 +175,7 @@ class NBWorker(WSClient):
                     f'WidgetsManager.update("{widget_key}", field="filepath", new_value="{value[1]}")\n'
                 )
             elif widget_type == "OutputDir":
-                sm = StorageManager(self.session_id, self.worker_id)
-                output_dir = sm.worker_output_dir()
+                output_dir = self.sm.worker_output_dir()
                 output_dir = output_dir.replace("\\", "\\\\")
                 code = f'WidgetsManager.update("{widget_key}", field="value", new_value="{output_dir}")'
 
@@ -237,7 +262,7 @@ class NBWorker(WSClient):
 
         if init_widgets:
             msg = {"purpose": Purpose.InitWidgets, "widgets": widgets_params}
-            log.debug("------------Init widgets")
+            log.debug("Init widgets")
             log.debug(msg)
             self.ws.send(json.dumps(msg))
         else:
@@ -254,16 +279,25 @@ class NBWorker(WSClient):
                 self.ws.send(json.dumps(msg))
 
     def initialize_outputdir(self):
-        sm = StorageManager(self.session_id, self.worker_id)
-        output_dir = sm.worker_output_dir()
+        output_dir = self.sm.worker_output_dir()
         output_dir = output_dir.replace("\\", "\\\\")
         self.nbrun.run_code(
             f"""import os\nos.environ["MERCURY_OUTPUTDIR"]="{output_dir}" """
         )
 
+    def install_new_packages(self):
+        if "127.0.0.1" not in self.ws_address and "localhost" not in self.ws_address:
+            fname = "requirements.txt"
+            if os.path.exists(fname):
+                log.debug(f"Install new packages from requirements.txt")
+                cmd = f"pip install -r {fname}"
+                self.nbrun.run_code(cmd)
+
     def init_notebook(self):
         log.debug(f"Init notebook, show_code={self.show_code()}")
 
+        self.sm.provision_uploaded_files()
+
         self.prev_nb = None
         self.prev_widgets = {}
         self.prev_body = ""
@@ -276,6 +310,9 @@ class NBWorker(WSClient):
             is_presentation=self.is_presentation(),
             reveal_theme=self.reveal_theme(),
         )
+
+        self.install_new_packages()
+
         # we need to initialize the output dir always
         # even if there is no OutputDir in the notebook
         self.initialize_outputdir()
@@ -284,46 +321,52 @@ class NBWorker(WSClient):
 
         self.nbrun.run_notebook(self.nb_original)
 
+        self.sm.sync_output_dir()
+
         # TODO: update params in db if needed"
         params = {}
         parse_params(nb2dict(self.nb_original), params)
 
         # update database ...
-        log.debug(f"Executed params {json.dumps(params, indent=4)}")
 
-        update_database = False
-        if params.get("title", "") != "" and self.notebook.title != params.get(
-            "title", ""
-        ):
-            self.notebook.title = params.get("title", "")
-            update_database = True
+        log.debug(f"Executed params {json.dumps(params, indent=4)}")
+        update_database = self.update_notebook(params)
+
+        # update_database = False
+        # if params.get("title", "") != "" and self.notebook.title != params.get(
+        #     "title", ""
+        # ):
+        #     self.notebook.title = params.get("title", "")
+        #     update_database = True
+
+        # nb_params = json.loads(self.notebook.params)
+        # for property in [
+        #     "show-code",
+        #     "show-prompt",
+        #     "continuous_update",
+        #     "static_notebook",
+        #     "description",
+        #     "show_sidebar",
+        #     "full_screen",
+        #     "allow_download",
+        # ]:
+        #     if params.get(property) is not None and nb_params.get(
+        #         property
+        #     ) != params.get(property):
+        #         nb_params[property] = params.get(property)
+        #         update_database = True
+        # # save widgets params
+        # if json.dumps(nb_params.get("params", {})) != json.dumps(
+        #     params.get("params", {})
+        # ):
+        #     nb_params["params"] = params["params"]
+        #     update_database = True
+
+        # if update_database:
+        #     self.notebook.params = json.dumps(nb_params)
+        #     self.notebook.save()
 
         nb_params = json.loads(self.notebook.params)
-        for property in [
-            "show-code",
-            "show-prompt",
-            "continuous_update",
-            "static_notebook",
-            "description",
-            "show_sidebar",
-            "full_screen",
-            "allow_download",
-        ]:
-            if params.get(property) is not None and nb_params.get(
-                property
-            ) != params.get(property):
-                nb_params[property] = params.get(property)
-                update_database = True
-        # save widgets params
-        if json.dumps(nb_params.get("params", {})) != json.dumps(
-            params.get("params", {})
-        ):
-            nb_params["params"] = params["params"]
-            update_database = True
-
-        if update_database:
-            self.notebook.params = json.dumps(nb_params)
-            self.notebook.save()
 
         self.nbrun.set_show_code_and_prompt(
             nb_params.get("show-code", False), nb_params.get("show-prompt", True)
@@ -349,30 +392,30 @@ class NBWorker(WSClient):
         self.send_widgets(self.nb, expected_widgets_keys=[], init_widgets=True)
         self.update_worker_state(WorkerState.Running)
 
-    def save_notebook(self):
-        log.debug(f"Save notebook")
-        # save nb in HTML
-        if self.is_presentation():
-            nb_body = self.nbrun.export_html(self.nb, full_header=True)
-        else:
-            nb_body = self.nbrun.export_html(self.nb, full_header=True)
+    # def save_notebook(self):
+    #     log.debug(f"Save notebook")
+    #     # save nb in HTML
+    #     if self.is_presentation():
+    #         nb_body = self.nbrun.export_html(self.nb, full_header=True)
+    #     else:
+    #         nb_body = self.nbrun.export_html(self.nb, full_header=True)
 
-        sm = StorageManager(self.session_id, self.worker_id)
-        nb_path = sm.save_nb_html(nb_body)
+    #     sm = StorageManager(self.session_id, self.worker_id)
+    #     nb_path = sm.save_nb_html(nb_body)
 
-        # create task with path to HTML file
-        task = Task.objects.create(
-            task_id=f"worker-{self.worker_id}",
-            session_id=self.session_id,
-            notebook_id=self.notebook_id,
-            state="DONE",
-            params=json.dumps(self.prev_widgets),
-            result=nb_path,
-        )
-        log.debug(f"Task ({task.id}) created")
+    #     # create task with path to HTML file
+    #     task = Task.objects.create(
+    #         task_id=f"worker-{self.worker_id}",
+    #         session_id=self.session_id,
+    #         notebook_id=self.notebook_id,
+    #         state="DONE",
+    #         params=json.dumps(self.prev_widgets),
+    #         result=nb_path,
+    #     )
+    #     log.debug(f"Task ({task.id}) created")
 
-        # send notice that nb saved
-        self.ws.send(json.dumps({"purpose": Purpose.SavedNotebook}))
+    #     # send notice that nb saved
+    #     self.ws.send(json.dumps({"purpose": Purpose.SavedNotebook}))
 
     def display_notebook(self, json_params):
         log.debug(f"Display notebook ({json_params})")
@@ -385,8 +428,7 @@ class NBWorker(WSClient):
         else:
             nb_body = self.nbrun.export_html(self.nb, full_header=True)
 
-        sm = StorageManager(self.session_id, self.worker_id)
-        _, nb_url = sm.save_nb_html(nb_body)
+        _, nb_url = self.sm.save_nb_html(nb_body)
 
         # send HTML url address
         self.ws.send(
@@ -405,8 +447,7 @@ class NBWorker(WSClient):
         nb_body = self.nbrun.export_html(self.nb, full_header=True)
 
         # export to PDF
-        sm = StorageManager(self.session_id, self.worker_id)
-        _, pdf_url = sm.save_nb_pdf(nb_body, self.is_presentation())
+        _, pdf_url = self.sm.save_nb_pdf(nb_body, self.is_presentation())
 
         # send PDF url
         self.ws.send(
