@@ -19,10 +19,10 @@ from django.contrib.auth.models import User
 from django.template.defaultfilters import slugify
 from django.utils.timezone import make_aware
 
-from apps.accounts.models import Site
+from apps.accounts.models import Site, SiteStatus
 from apps.nb.exporter import Exporter
 from apps.notebooks.models import Notebook
-from apps.notebooks.slides_themes import SlidesThemes
+from apps.storage.s3utils import S3
 from apps.tasks.models import Task
 from apps.tasks.notify import validate_notify
 from apps.ws.utils import parse_params
@@ -103,14 +103,19 @@ def make_unique(slug):
 
 
 def task_init_notebook(
-    notebook_path, render_html=True, is_watch_mode=False, notebook_id=None
+    notebook_path,
+    render_html=True,
+    is_watch_mode=False,
+    notebook_id=None,
+    bucket_key=None,
+    site=None,
+    user=None,
 ):
     try:
         params = {
             "title": "",
             "author": "Please provide author",
             "description": "Please provide description",
-            "share": "public",
             "output": "app",
             "format": {},
             "schedule": "",
@@ -131,7 +136,6 @@ def task_init_notebook(
         notebook_title = params.get("title", "")
         if notebook_title == "":
             notebook_title = nb_default_title(notebook_path)
-        notebook_share = params.get("share", "public")
         notebook_output = params.get("output", "app")
         notebook_format = params.get("format", {})
         notebook_schedule = params.get("schedule", "")
@@ -150,11 +154,6 @@ def task_init_notebook(
                     f"The schedule ({notebook_schedule}) is not valid. {str(e)} Please check schedule at https://crontab.guru"
                 )
 
-        # make sure that there are commas and no spaces between commas
-        notebook_share = (
-            "," + ",".join([i.strip() for i in notebook_share.split(",")]) + ","
-        )
-
         notebook_slug = "some-slug"
         if notebook_id is None:
             notebook_slug = params.get("slug", "")
@@ -215,39 +214,50 @@ def task_init_notebook(
         parse_errors = validate_notify(notebook_notify)
 
         if notebook_id is None:
-            site, user = None, None
+            if user is None:
+                if not User.objects.filter(username="developer"):
+                    user = User.objects.create_user(
+                        username="developer",
+                        email="developer@example.com",
+                        password="developer",
+                    )
+                    EmailAddress.objects.create(
+                        user=user, email=user.email, verified=True, primary=True
+                    )
+                else:
+                    user = User.objects.get(username="developer")
+            if site is None:
+                if not Site.objects.filter(slug="single-site"):
+                    site = Site.objects.create(
+                        title="Mercury",
+                        slug="single-site",
+                        share=Site.PUBLIC,
+                        created_by=user,
+                        status=SiteStatus.READY,
+                    )
+                else:
+                    site = Site.objects.get(slug="single-site")
 
-            if not User.objects.filter(username="developer"):
-                user = User.objects.create_user(
-                    username="developer",
-                    email="developer@example.com",
-                    password="developer",
+            bucket_key_fname = ""
+            if bucket_key is not None:
+                s3 = S3()
+                bucket_key_fname = bucket_key.replace(
+                    "<replace>", f"{notebook_output_file}.html"
                 )
-                EmailAddress.objects.create(
-                    user=user, email=user.email, verified=True, primary=True
+                s3.upload_file(
+                    os.path.join(settings.MEDIA_ROOT, f"{notebook_output_file}.html"),
+                    bucket_key_fname,
                 )
-            else:
-                user = User.objects.get(username="developer")
-            if not Site.objects.filter(slug="single-site"):
-                site = Site.objects.create(
-                    title="Mercury",
-                    slug="single-site",
-                    share=Site.PUBLIC,
-                    created_by=user,
-                )
-            else:
-                site = Site.objects.get(slug="single-site")
 
             notebook = Notebook(
                 title=notebook_title,
                 slug=notebook_slug,
                 path=os.path.abspath(notebook_path),
                 state="WATCH_READY" if is_watch_mode else "READY",
-                share=notebook_share,
                 params=json.dumps(params),
-                default_view_path=os.path.join(
-                    settings.MEDIA_URL, f"{notebook_output_file}.html"
-                ),
+                default_view_path=bucket_key_fname
+                if bucket_key is not None
+                else os.path.join(settings.MEDIA_URL, f"{notebook_output_file}.html"),
                 file_updated_at=make_aware(
                     datetime.fromtimestamp(os.path.getmtime(notebook_path))
                 ),
@@ -265,7 +275,6 @@ def task_init_notebook(
             notebook.slug = notebook_slug
             notebook.path = os.path.abspath(notebook_path)
             notebook.state = "WATCH_READY" if is_watch_mode else "READY"
-            notebook.share = notebook_share
             notebook.params = json.dumps(params)
             # remove old default view
             if os.path.exists(notebook.default_view_path):
