@@ -7,12 +7,12 @@ from .manager import WidgetsManager
 
 
 class MultiSelect:
-    def __init__(self, value=[], choices=[], label=""):
+    def __init__(self, value=[], choices=[], label="", url_key=""):
         if value is None and len(choices) > 1:
             value = [choices[0]]
 
         self.code_uid = WidgetsManager.get_code_uid("MultiSelect")
-
+        self.url_key = url_key
         if WidgetsManager.widget_exists(self.code_uid):
             self.select = WidgetsManager.get_widget(self.code_uid)
             if list(self.select.options) != choices:
@@ -63,6 +63,7 @@ class MultiSelect:
                 "label": self.select.description,
                 "model_id": self.select.model_id,
                 "code_uid": self.code_uid,
+                "url_key": self.url_key,
             }
             data["application/mercury+json"] = json.dumps(view, indent=4)
             if "text/plain" in data:
